<?php

namespace Hospital\Clinic\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Hospital\Clinic\Interfaces\ClinicRepositoryInterface;

class ClinicPublicController extends BaseController
{
    // use ClinicWorkflow;

    /**
     * Constructor.
     *
     * @param type \Hospital\Clinic\Interfaces\ClinicRepositoryInterface $clinic
     *
     * @return type
     */
    public function __construct(ClinicRepositoryInterface $clinic)
    {
        $this->repository = $clinic;
        parent::__construct();
    }

    /**
     * Show clinic's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $clinics = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$clinic::$clinic.names'))
            ->view('$clinic::public.clinic.index')
            ->data(compact('$clinics'))
            ->output();
    }

    /**
     * Show clinic's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $clinics = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$clinic::$clinic.names'))
            ->view('$clinic::public.clinic.index')
            ->data(compact('$clinics'))
            ->output();
    }

    /**
     * Show clinic.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $clinic = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$clinic->name . trans('$clinic::$clinic.name'))
            ->view('$clinic::public.clinic.show')
            ->data(compact('$clinic'))
            ->output();
    }

}
