<?php

namespace Hospital\Clinic\Policies;

use Litepie\User\Contracts\UserPolicy;
use Hospital\Clinic\Models\Clinic;

class ClinicPolicy
{

    /**
     * Determine if the given user can view the clinic.
     *
     * @param UserPolicy $user
     * @param Clinic $clinic
     *
     * @return bool
     */
    public function view(UserPolicy $user, Clinic $clinic)
    {
        if ($user->canDo('clinic.clinic.view') && $user->isAdmin()) {
            return true;
        }

        return $clinic->user_id == user_id() && $clinic->user_type == user_type();
    }

    /**
     * Determine if the given user can create a clinic.
     *
     * @param UserPolicy $user
     * @param Clinic $clinic
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('clinic.clinic.create');
    }

    /**
     * Determine if the given user can update the given clinic.
     *
     * @param UserPolicy $user
     * @param Clinic $clinic
     *
     * @return bool
     */
    public function update(UserPolicy $user, Clinic $clinic)
    {
        if ($user->canDo('clinic.clinic.edit') && $user->isAdmin()) {
            return true;
        }

        return $clinic->user_id == user_id() && $clinic->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given clinic.
     *
     * @param UserPolicy $user
     * @param Clinic $clinic
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Clinic $clinic)
    {
        return $clinic->user_id == user_id() && $clinic->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given clinic.
     *
     * @param UserPolicy $user
     * @param Clinic $clinic
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Clinic $clinic)
    {
        if ($user->canDo('clinic.clinic.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given clinic.
     *
     * @param UserPolicy $user
     * @param Clinic $clinic
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Clinic $clinic)
    {
        if ($user->canDo('clinic.clinic.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
